@@ -12,7 +12,7 @@ use URI::Escape 'uri_escape';
 use Convert::Base32 qw( encode_base32 decode_base32 );
 use Carp 'croak';
 
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.01'; # VERSION
 
 my @accessors = qw( secret secret32 issuer key_id otpauth );
 __PACKAGE__->mk_accessors(@accessors);
@@ -135,7 +135,7 @@ Auth::GoogleAuth - Google Authenticator TBOT Abstraction
 
 =head1 VERSION
 
-version 1.00
+version 1.01
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Auth-GoogleAuth.svg)](https://travis-ci.org/gryphonshafer/Auth-GoogleAuth)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Auth-GoogleAuth/badge.png)](https://coveralls.io/r/gryphonshafer/Auth-GoogleAuth)
@@ -162,8 +162,14 @@ version 1.00
     $auth->clear;
 
     my $url_0 = $auth->qr_code;
-    my $url_1 = $auth->qr_code( 'bv5o3disbutz4tl3', 'gryphon@cpan.org', 'Gryphon Shafer' );
-    my $url_2 = $auth->qr_code( 'bv5o3disbutz4tl3', 'gryphon@cpan.org', 'Gryphon Shafer', 1 );
+    my $url_1 = $auth->qr_code(
+        'bv5o3disbutz4tl3', # secret32
+        'gryphon@cpan.org', # key_id
+        'Gryphon Shafer',   # issuer
+    );
+    my $url_2 = $auth->qr_code(
+        'bv5o3disbutz4tl3', 'gryphon@cpan.org', 'Gryphon Shafer', 1,
+    );
 
     my $otpauth = $auth->otpauth;
 
@@ -171,7 +177,13 @@ version 1.00
     my $code_1 = $auth->code( 'utz4tl3bv5o3disb', 1438643789, 30 );
 
     my $verification_0 = $auth->verify('879364');
-    my $verification_1 = $auth->verify( '879364', 1, 'utz4tl3bv5o3disb', 1438643820, 30 );
+    my $verification_1 = $auth->verify(
+        '879364',           # code
+        1,                  # range
+        'utz4tl3bv5o3disb', # secret32
+        1438643820,         # timestamp (defaults to now)
+        30,                 # interval (default 30)
+    );
 
 =head1 DESCRIPTION
 
@@ -263,7 +275,9 @@ on the data either in the object or provided to this method.
 You can optionally add a final true value, and if you do, the method will
 return the generated otpauth key URI rather than the Google Chart API URL.
 
-    my $url_2 = $auth->qr_code( 'bv5o3disbutz4tl3', 'gryphon@cpan.org', 'Gryphon Shafer', 1 );
+    my $url_2 = $auth->qr_code(
+        'bv5o3disbutz4tl3', 'gryphon@cpan.org', 'Gryphon Shafer', 1,
+    );
 
 =head2 code
 
